"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var ng_bootstrap_1 = require("@ng-bootstrap/ng-bootstrap");
var org_interface_1 = require("../../../common/interface/org.interface");
var __1 = require("../../../../..");
var OrganizationManagementComponent = /** @class */ (function () {
    function OrganizationManagementComponent(orgInterface, modalService) {
        var _this = this;
        this.orgInterface = orgInterface;
        this.modalService = modalService;
        this.nodeViewType = 'edit'; // 右侧查看状态 edit | add
        this.mockData = []; // 模拟数据
        this.treeOptions = {
            actionBtn: [
                {
                    text: '新增',
                    cls: 'action-add',
                    showText: true,
                    fn: function (nodeData) {
                        _this.addOrgElement(nodeData);
                    }
                }, {
                    text: '删除',
                    cls: 'action-del',
                    showText: true,
                    rootHide: true,
                    fn: function (nodeData) {
                        _this.delOrgElement(nodeData);
                    }
                }
            ],
            iconCls: {
                expand: 'tree-icon-expand',
                file: 'tree-icon-file',
                folder: 'tree-icon-folder'
            },
        }; // 树节点操作按钮配置
        this.treeSearch = {
            text: '',
            searching: false,
            result: [],
        };
    }
    OrganizationManagementComponent.prototype.ngOnInit = function () {
        this.getOrgTreeData();
    };
    OrganizationManagementComponent.prototype.ngOnDestroy = function () {
        this.destroyPromisse();
    };
    // 当组件被移除的时候，销毁该组件的请求
    OrganizationManagementComponent.prototype.destroyPromisse = function () {
        this.getOrgTreePromisse && this.getOrgTreePromisse.unsubscribe();
        this.addOrgPromisse && this.addOrgPromisse.unsubscribe();
        this.editOrgPromisse && this.editOrgPromisse.unsubscribe();
        this.delOrgPromisse && this.delOrgPromisse.unsubscribe();
        this.getOrgPromisse && this.getOrgPromisse.unsubscribe();
    };
    // 获取组织树数据
    OrganizationManagementComponent.prototype.getOrgTreeData = function () {
        var _this = this;
        if (this.getOrgTreePromisse) {
            this.getOrgTreePromisse.unsubscribe();
        }
        this.getOrgTreePromisse = this.orgInterface.getOrgTreeData({
            id: 1
        }).subscribe(function (res) {
            _this.mockData = res['result'];
        }, function (err) {
            alert(JSON.stringify(err));
        });
    };
    // 节点点击事件
    OrganizationManagementComponent.prototype.nodeClick = function (nodeData) {
        this.nodeViewType = 'edit';
        this.tree.selectTreeNode(nodeData);
        this.selectOrgData = nodeData;
        this.queryOrgElement(nodeData);
    };
    // 获取单个组织详细信息
    OrganizationManagementComponent.prototype.queryOrgElement = function (nodeData) {
        var _this = this;
        if (this.getOrgPromisse) {
            this.getOrgPromisse.unsubscribe();
        }
        this.getOrgPromisse = this.orgInterface.queryOrgElement({
            id: nodeData.id
        }).subscribe(function (res) {
            _this.changeCurrentOrgData(res['result'].torgEntity);
        }, function (err) {
            alert(JSON.stringify(err));
        });
    };
    // 切换组织节点
    OrganizationManagementComponent.prototype.changeCurrentOrgData = function (data) {
        var _this = this;
        this.currentOrgData = null;
        setTimeout(function () {
            _this.currentOrgData = data;
        }, 1);
    };
    // 节点删除事件
    OrganizationManagementComponent.prototype.delOrgElement = function (nodeData) {
        var _this = this;
        var childrenNode = this.tree.findChildrensNodeByNode(nodeData);
        if (childrenNode.length > 0) {
            var ids_1 = [];
            for (var i = 0; i < childrenNode.length; i++) {
                ids_1.push(childrenNode[i].id);
            }
            var modalDialog = this.modalService.open(__1.ModalTipComponent, {
                backdrop: 'static'
            });
            modalDialog.result.then(function (value) {
                if (_this.delOrgPromisse) {
                    _this.delOrgPromisse.unsubscribe();
                }
                _this.delOrgPromisse = _this.orgInterface.delOrgElement({
                    ids: (ids_1.join(',') + '')
                }).subscribe(function (res) {
                    _this.tree.deleteNodeById(ids_1[0]);
                }, function (err) {
                    alert(JSON.stringify(err));
                });
            }).catch(function (reason) {
            });
        }
    };
    // 节点新增事件
    OrganizationManagementComponent.prototype.addOrgElement = function (item) {
        this.nodeViewType = 'add';
        this.parentOrgForAdd = item;
        this.changeCurrentOrgData({
            'id': '',
            'orgName': '',
            'parentId': item.id,
            'uppOrgName': item.orgName,
            'state': '1',
            'remark': ''
        });
    };
    // 模糊搜索组织名称
    OrganizationManagementComponent.prototype.searchTreeNode = function (ev) {
        this.resetTreeSearch();
        if (!this.treeSearch.text) {
            return;
        }
        this.treeSearch.searching = true;
        this.treeSearch.result = this.tree.fuzzySearchNodesByKey(this.treeSearch.text, 'orgName');
        this.tree.lighthightNodes(this.treeSearch.result);
        this.tree.expandNodes(this.treeSearch.result);
        this.treeSearch.searching = false;
    };
    // 重置树节点的搜索状态
    OrganizationManagementComponent.prototype.resetTreeSearch = function () {
        this.tree.removeLighthightNodes(this.treeSearch.result);
        this.treeSearch.searching = false;
        this.treeSearch.result = [];
    };
    // 保存组织回掉方法
    OrganizationManagementComponent.prototype.saveOrgElement = function (data) {
        var _this = this;
        if (this.nodeViewType == 'add') {
            data.parentId = this.parentOrgForAdd.id;
            var loadingModal_1 = this.modalService.open('loading', {
                backdrop: 'static'
            });
            if (this.addOrgPromisse) {
                this.addOrgPromisse.unsubscribe();
            }
            this.addOrgPromisse = this.orgInterface.addOrgElement(data).subscribe(function (res) {
                loadingModal_1.close();
                var result = res['result'].torgEntity;
                var node = _this.tree.insertNode(result, _this.parentOrgForAdd);
                _this.tree.selectTreeNode(node);
                _this.selectOrgData = node;
                _this.nodeViewType = 'edit';
                _this.changeCurrentOrgData(node);
            }, function (err) {
                loadingModal_1.close();
                alert(JSON.stringify(err));
            });
        }
        else if (this.nodeViewType == 'edit') {
            if (this.editOrgPromisse) {
                this.editOrgPromisse.unsubscribe();
            }
            this.editOrgPromisse = this.orgInterface.updateOrgElement(data).subscribe(function (res) {
                _this.tree.updateNodeData(data, ['orgName', 'state', 'remark']);
            }, function (err) {
                alert(JSON.stringify(err));
            });
        }
    };
    __decorate([
        core_1.ViewChild('tree'),
        __metadata("design:type", Object)
    ], OrganizationManagementComponent.prototype, "tree", void 0);
    OrganizationManagementComponent = __decorate([
        core_1.Component({
            moduleId: module.id,
            templateUrl: './organization.management.component.html',
            styleUrls: ['./organization.management.component.css']
        }),
        __metadata("design:paramtypes", [org_interface_1.OrgInterface,
            ng_bootstrap_1.NgbModal])
    ], OrganizationManagementComponent);
    return OrganizationManagementComponent;
}());
exports.OrganizationManagementComponent = OrganizationManagementComponent;
//# sourceMappingURL=organization.management.component.js.map